@@ -349,7 +349,7 @@ class UUID(StringPattern):
         with warnings.catch_warnings():
             warnings.simplefilter("once")
             try:
-                uuid.UUID(str(value))
+                uuid.UUID("%s" % value)
             except Exception:
                 # This is to ensure no breaking behaviour for current
                 # users
@@ -359,10 +359,12 @@ class UUID(StringPattern):
                               "release. Please update your "
                               "code to input valid UUIDs or accept "
                               "ValueErrors for invalid UUIDs. See "
-                              "http://docs.openstack.org/developer/oslo.versionedobjects/api/fields.html#oslo_versionedobjects.fields.UUIDField "  # noqa
-                              "for further details" % value, FutureWarning)
+                              "https://docs.openstack.org/oslo.versionedobjects/latest/reference/fields.html#oslo_versionedobjects.fields.UUIDField "  # noqa
+                              "for further details" %
+                              repr(value).encode('utf8'),
+                              FutureWarning)
 
-            return str(value)
+            return "%s" % value
 
 
 class MACAddress(StringPattern):
@@ -1036,7 +1038,7 @@ class UUIDField(AutoTypedField):
     your own objects/fields.py
 
     :Example:
-         .. code-block:: python
+        .. code-block:: python
 
             import oslo_versionedobjects.fields as ovo_fields
 
@@ -1049,8 +1051,8 @@ class UUIDField(AutoTypedField):
             class UUIDField(ovo_fields.AutoTypedField):
                 AUTO_TYPE = UUID()
 
-        and then in your objects use
-        ``<your_projects>.object.fields.UUIDField``.
+    and then in your objects use
+    ``<your_projects>.object.fields.UUIDField``.
 
     This will become default behaviour in the future.
     """
